==> warnings-2.7-sources.jar: hudson/plugins/warnings/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.warnings;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * New zero warnings highscore: no warnings for {0} days!
     * 
     */
    public static String Warnings_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no warnings for {0} days!
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleHighScore", arg1);
    }

    /**
     *  1 warning
     * 
     */
    public static String Warnings_ResultAction_OneWarning() {
        return holder.format("Warnings.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Warnings_ResultAction_OneWarning() {
        return new Localizable(holder, "Warnings.ResultAction.OneWarning");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Warnings_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * Compiler Warnings: {0} warnings found.
     * 
     */
    public static String Warnings_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Warnings.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Compiler Warnings: {0} warnings found.
     * 
     */
    public static Localizable _Warnings_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Scan log files for compiler warnings
     * 
     */
    public static String Warnings_Publisher_Name() {
        return holder.format("Warnings.Publisher.Name");
    }

    /**
     * Scan log files for compiler warnings
     * 
     */
    public static Localizable _Warnings_Publisher_Name() {
        return new Localizable(holder, "Warnings.Publisher.Name");
    }

    /**
     * Compiler Warnings Trend
     * 
     */
    public static String Warnings_Trend_Name() {
        return holder.format("Warnings.Trend.Name");
    }

    /**
     * Compiler Warnings Trend
     * 
     */
    public static Localizable _Warnings_Trend_Name() {
        return new Localizable(holder, "Warnings.Trend.Name");
    }

    /**
     * Fixed Compiler Warnings Warnings
     * 
     */
    public static String Warnings_FixedWarnings_Detail_header() {
        return holder.format("Warnings.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Compiler Warnings Warnings
     * 
     */
    public static Localizable _Warnings_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Warnings.FixedWarnings.Detail.header");
    }

    /**
     * Compiler Warnings: 1 warning found.
     * 
     */
    public static String Warnings_ResultAction_HealthReportSingleItem() {
        return holder.format("Warnings.ResultAction.HealthReportSingleItem");
    }

    /**
     * Compiler Warnings: 1 warning found.
     * 
     */
    public static Localizable _Warnings_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Warnings.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Warnings_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String Warnings_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     *  1 new warning
     * 
     */
    public static String Warnings_ResultAction_OneNewWarning() {
        return holder.format("Warnings.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Warnings_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Warnings.ResultAction.OneNewWarning");
    }

    /**
     * New Compiler Warnings Warnings
     * 
     */
    public static String Warnings_NewWarnings_Detail_header() {
        return holder.format("Warnings.NewWarnings.Detail.header");
    }

    /**
     * New Compiler Warnings Warnings
     * 
     */
    public static Localizable _Warnings_NewWarnings_Detail_header() {
        return new Localizable(holder, "Warnings.NewWarnings.Detail.header");
    }

    /**
     * Compiler Warnings: no warnings found.
     * 
     */
    public static String Warnings_ResultAction_HealthReportNoItem() {
        return holder.format("Warnings.ResultAction.HealthReportNoItem");
    }

    /**
     * Compiler Warnings: no warnings found.
     * 
     */
    public static Localizable _Warnings_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Warnings.ResultAction.HealthReportNoItem");
    }

    /**
     * New zero warnings highscore: no warnings since yesterday!
     * 
     */
    public static String Warnings_ResultAction_OneHighScore() {
        return holder.format("Warnings.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no warnings since yesterday!
     * 
     */
    public static Localizable _Warnings_ResultAction_OneHighScore() {
        return new Localizable(holder, "Warnings.ResultAction.OneHighScore");
    }

    /**
     * Compiler Warnings
     * 
     */
    public static String Warnings_ProjectAction_Name() {
        return holder.format("Warnings.ProjectAction.Name");
    }

    /**
     * Compiler Warnings
     * 
     */
    public static Localizable _Warnings_ProjectAction_Name() {
        return new Localizable(holder, "Warnings.ProjectAction.Name");
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String Warnings_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("Warnings.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _Warnings_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static String Warnings_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleWarnings", arg1);
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Warnings_ResultAction_OneFixedWarning() {
        return holder.format("Warnings.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Warnings_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Warnings.ResultAction.OneFixedWarning");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String Warnings_ResultAction_OneNoHighScore() {
        return holder.format("Warnings.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Warnings_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "Warnings.ResultAction.OneNoHighScore");
    }

}

==> warnings-2.12-sources.jar: hudson/plugins/warnings/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.warnings;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * New zero warnings highscore: no warnings for {0} days!
     * 
     */
    public static String Warnings_ResultAction_MultipleHighScore(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleHighScore", arg1);
    }

    /**
     * New zero warnings highscore: no warnings for {0} days!
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleHighScore(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleHighScore", arg1);
    }

    /**
     *  1 warning
     * 
     */
    public static String Warnings_ResultAction_OneWarning() {
        return holder.format("Warnings.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _Warnings_ResultAction_OneWarning() {
        return new Localizable(holder, "Warnings.ResultAction.OneWarning");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String Warnings_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * Compiler Warnings: {0} warnings found.
     * 
     */
    public static String Warnings_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("Warnings.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Compiler Warnings: {0} warnings found.
     * 
     */
    public static Localizable _Warnings_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Scan for compiler warnings
     * 
     */
    public static String Warnings_Publisher_Name() {
        return holder.format("Warnings.Publisher.Name");
    }

    /**
     * Scan for compiler warnings
     * 
     */
    public static Localizable _Warnings_Publisher_Name() {
        return new Localizable(holder, "Warnings.Publisher.Name");
    }

    /**
     * Compiler Warnings Trend
     * 
     */
    public static String Warnings_Trend_Name() {
        return holder.format("Warnings.Trend.Name");
    }

    /**
     * Compiler Warnings Trend
     * 
     */
    public static Localizable _Warnings_Trend_Name() {
        return new Localizable(holder, "Warnings.Trend.Name");
    }

    /**
     * Fixed Compiler Warnings Warnings
     * 
     */
    public static String Warnings_FixedWarnings_Detail_header() {
        return holder.format("Warnings.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Compiler Warnings Warnings
     * 
     */
    public static Localizable _Warnings_FixedWarnings_Detail_header() {
        return new Localizable(holder, "Warnings.FixedWarnings.Detail.header");
    }

    /**
     * Compiler Warnings: 1 warning found.
     * 
     */
    public static String Warnings_ResultAction_HealthReportSingleItem() {
        return holder.format("Warnings.ResultAction.HealthReportSingleItem");
    }

    /**
     * Compiler Warnings: 1 warning found.
     * 
     */
    public static Localizable _Warnings_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "Warnings.ResultAction.HealthReportSingleItem");
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String Warnings_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static String Warnings_ResultAction_MultipleNoHighScore(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     * Still {0} days before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleNoHighScore(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleNoHighScore", arg1);
    }

    /**
     *  1 new warning
     * 
     */
    public static String Warnings_ResultAction_OneNewWarning() {
        return holder.format("Warnings.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _Warnings_ResultAction_OneNewWarning() {
        return new Localizable(holder, "Warnings.ResultAction.OneNewWarning");
    }

    /**
     * New Compiler Warnings Warnings
     * 
     */
    public static String Warnings_NewWarnings_Detail_header() {
        return holder.format("Warnings.NewWarnings.Detail.header");
    }

    /**
     * New Compiler Warnings Warnings
     * 
     */
    public static Localizable _Warnings_NewWarnings_Detail_header() {
        return new Localizable(holder, "Warnings.NewWarnings.Detail.header");
    }

    /**
     * Compiler Warnings: no warnings found.
     * 
     */
    public static String Warnings_ResultAction_HealthReportNoItem() {
        return holder.format("Warnings.ResultAction.HealthReportNoItem");
    }

    /**
     * Compiler Warnings: no warnings found.
     * 
     */
    public static Localizable _Warnings_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "Warnings.ResultAction.HealthReportNoItem");
    }

    /**
     * New zero warnings highscore: no warnings since yesterday!
     * 
     */
    public static String Warnings_ResultAction_OneHighScore() {
        return holder.format("Warnings.ResultAction.OneHighScore");
    }

    /**
     * New zero warnings highscore: no warnings since yesterday!
     * 
     */
    public static Localizable _Warnings_ResultAction_OneHighScore() {
        return new Localizable(holder, "Warnings.ResultAction.OneHighScore");
    }

    /**
     * Compiler Warnings
     * 
     */
    public static String Warnings_ProjectAction_Name() {
        return holder.format("Warnings.ProjectAction.Name");
    }

    /**
     * Compiler Warnings
     * 
     */
    public static Localizable _Warnings_ProjectAction_Name() {
        return new Localizable(holder, "Warnings.ProjectAction.Name");
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static String Warnings_ResultAction_NoWarningsSince(Object arg1) {
        return holder.format("Warnings.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * No warnings since build {0}.
     * 
     */
    public static Localizable _Warnings_ResultAction_NoWarningsSince(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.NoWarningsSince", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static String Warnings_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("Warnings.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _Warnings_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "Warnings.ResultAction.MultipleWarnings", arg1);
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String Warnings_ResultAction_OneFixedWarning() {
        return holder.format("Warnings.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _Warnings_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "Warnings.ResultAction.OneFixedWarning");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static String Warnings_ResultAction_OneNoHighScore() {
        return holder.format("Warnings.ResultAction.OneNoHighScore");
    }

    /**
     * Still one day before reaching the previous zero warnings highscore.
     * 
     */
    public static Localizable _Warnings_ResultAction_OneNoHighScore() {
        return new Localizable(holder, "Warnings.ResultAction.OneNoHighScore");
    }

}
